@@ -22,11 +22,7 @@
 import ldap
 import logging
 
-from django.core.exceptions import ObjectDoesNotExist, ImproperlyConfigured
-from django.conf import settings
-
-if not (hasattr(settings, 'LDAP_GROUPS_SERVER_URI') and hasattr(settings, 'LDAP_GROUPS_BASE_DN')):
-    raise ImproperlyConfigured("LDAP Groups required settings LDAP_GROUPS_SERVER_URI and LDAP_GROUPS_BASE_DN are not configured.")
+from .exceptions import ObjectDoesNotExist, ImproperlyConfigured
 
 logger = logging.getLogger(__name__)
 
@@ -34,34 +30,88 @@ logger = logging.getLogger(__name__)
 class ADGroup:
     """Add members to, remove members from, and view members of Active Directory groups."""
 
-    USER_SEARCH = {
-        'base_dn': settings.LDAP_GROUPS_BASE_DN,
-        'scope': ldap.SCOPE_SUBTREE,
-        'filter_string': "(&(objectClass=user)(" + getattr(settings, 'LDAP_GROUPS_USER_LOOKUP_ATTRIBUTE', 'sAMAccountName') + "=%s))",
-        'attribute_list': ['distinguishedName']
-    }
 
-    GROUP_MEMBER_SEARCH = {
-        'base_dn': settings.LDAP_GROUPS_BASE_DN,
-        'scope': ldap.SCOPE_SUBTREE,
-        'filter_string': "(&(objectCategory=user)(memberOf=%s))",
-        'attribute_list': getattr(settings, 'LDAP_GROUPS_ATTRIBUTE_LIST', ['displayName', 'sAMAccountName', 'distinguishedName'])
-    }
-
-    def __init__(self, group_dn):
+    def __init__(self, group_dn, server_uri=None, base_dn=None, user_lookup_attr=None, attr_list=None, bind_dn=None, bind_password=None):
         """ Create an AD group object and establish an ldap search connection.
+            Any arguments other than group_dn are pulled from django settings
+            if they aren't passed in.
 
         :param group_dn: The distinguished name of the active directory group to be modified.
         :type group_dn: str
+        
+        :param server_uri: (Required) The ldap server uri. Pulled from Django settings if None.
+        :type server_uri: str
+        :param base_dn: (Required) The ldap base dn. Pulled from Django settings if None.
+        :type base_dn: str
+        :param user_lookup_attr: The attribute used in user searches. Default is 'sAMAccountName'.
+        :type user_lookup_attr: str
+        :param attr_list: A list of attributes to be pulled for each member of the AD group.
+        :type attr_list: list
+        :param bind_dn: A user used to bind to the AD. Necessary for any group modifications.
+        :type bind_dn: str
+        :param bind_password: The bind user's password. Necessary for any group modifications.
+        :type bind_password: str
 
         """
+        
+        # Attempt to grab settings from Django, fall back to init arguments if django is not used
+        try:
+            from django.conf import settings
+        except ImportError:
+            if not (server_uri and base_dn):
+                raise ImproperlyConfigured("A server_uri and base_dn must be passed as arguments if django settings are not used.")
+            else:
+                self.server_uri = server_uri
+                self.base_dn = base_dn
+            
+            self.user_lookup_attr = user_lookup_attr if user_lookup_attr else 'sAMAccountName'
+            self.attr_list = attr_list if attr_list else ['displayName', 'sAMAccountName', 'distinguishedName']
+            
+            self.bind_dn = bind_dn
+            self.bind_password = bind_password
+        else:
+            if hasattr(settings, 'LDAP_GROUPS_SERVER_URI') and hasattr(settings, 'LDAP_GROUPS_BASE_DN'):
+                if not server_uri:
+                    self.server_uri = getattr(settings, 'LDAP_GROUPS_SERVER_URI')
+                if not base_dn:
+                    self.base_dn = getattr(settings, 'LDAP_GROUPS_BASE_DN')
+            else:
+                raise ImproperlyConfigured("LDAP Groups required settings LDAP_GROUPS_SERVER_URI and LDAP_GROUPS_BASE_DN are not configured in django settings file.")
+        
+            if not user_lookup_attr:
+                self.user_lookup_attr = getattr(settings, 'LDAP_GROUPS_USER_LOOKUP_ATTRIBUTE', 'sAMAccountName')
+            
+            if not attr_list:
+                self.attr_list = getattr(settings, 'LDAP_GROUPS_ATTRIBUTE_LIST', ['displayName', 'sAMAccountName', 'distinguishedName'])
+            
+            if not bind_dn:
+                self.bind_dn = getattr(settings, 'LDAP_GROUPS_BIND_DN', None)
+            
+            if not bind_password:
+                self.bind_password = getattr(settings, 'LDAP_GROUPS_BIND_PASSWORD', None)
+        
+        # Initialize search objects
+        self.USER_SEARCH = {
+            'base_dn': self.base_dn,
+            'scope': ldap.SCOPE_SUBTREE,
+            'filter_string': "(&(objectClass=user)(" + self.user_lookup_attr + "=%s))",
+            'attribute_list': ['distinguishedName']
+        }
 
-        self.group_dn = group_dn
+        self.GROUP_MEMBER_SEARCH = {
+            'base_dn': self.base_dn,
+            'scope': ldap.SCOPE_SUBTREE,
+            'filter_string': "(&(objectCategory=user)(memberOf=%s))",
+            'attribute_list': self.attr_list
+        }
+        
+
+        self.group_dn = group_dn        
         ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, 0)
-        self.ldap_connection = ldap.initialize(settings.LDAP_GROUPS_SERVER_URI)
+        self.ldap_connection = ldap.initialize(self.server_uri)
 
-        if settings.LDAP_GROUPS_BIND_DN and settings.LDAP_GROUPS_BIND_PASSWORD:
-            self.ldap_connection.simple_bind_s(settings.LDAP_GROUPS_BIND_DN, settings.LDAP_GROUPS_BIND_PASSWORD)
+        if self.bind_dn and self.bind_password:
+            self.ldap_connection.simple_bind_s(self.bind_dn, self.bind_password)
         else:
             logger.warning("LDAP Bind Credentials are not set. Group modification methods will most likely fail.")
             self.ldap_connection.simple_bind_s()
